;; Generated package description from denote-menu.el  -*- no-byte-compile: t -*-
(define-package "denote-menu" "1.1.1" "View denote files in a tabulated list." '((emacs "28.1") (denote "1.2.0")) :commit "8e67c1a326bda7b824252548a1e5e46c7f840c49" :authors '(("Mohamed Suliman" . "sulimanm@tcd.ie")) :maintainer '("Mohamed Suliman" . "sulimanm@tcd.ie") :url "https://github.com/namilus/denote-menu")
